package com.yunfeiyun.agmp.pts.mapper;

import java.util.List;
import com.yunfeiyun.agmp.pts.domain.PtsTutorial;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author 杨晓辉
 * @date 2023-05-23
 */
public interface PtsTutorialMapper 
{
    /**
     * 查询
     * 
     * @param tutorialId
     * @return 【请填写功能名称】
     */
    public PtsTutorial selectPtsTutorialByTutorialId(PtsTutorial ptsTutorial);

    /**
     * 查询列表
     * 
     * @param ptsTutorial
     * @return 集合
     */
    public List<PtsTutorial> selectPtsTutorialList(PtsTutorial ptsTutorial);

    /**
     * 新增
     * 
     * @param ptsTutorial
     * @return 结果
     */
    public int insertPtsTutorial(PtsTutorial ptsTutorial);

    /**
     * 修改
     * 
     * @param ptsTutorial
     * @return 结果
     */
    public int updatePtsTutorial(PtsTutorial ptsTutorial);

    /**
     * 删除
     * 
     * @param tutorialId
     * @return 结果
     */
    public int deletePtsTutorialByTutorialId(String tutorialId);

    /**
     * 批量删除
     * 
     * @param tutorialIds
     * @return 结果
     */
    public int deletePtsTutorialByTutorialIds(String[] tutorialIds);
}
